// ignore_for_file: non_constant_identifier_names

class ContactConsentTrackingPermissionModel {
  final bool? TermsAndConditions;
  final bool? PrivacyOverview;
  final bool? NecessaryCookies;
  final bool? PreferencesCookies;
  final bool? AnalyticsCookies;
  final bool? MarketingCookies;
  final bool? SocialMediaCookies;

  ContactConsentTrackingPermissionModel({
    required this.TermsAndConditions,
    required this.PrivacyOverview,
    required this.NecessaryCookies,
    required this.PreferencesCookies,
    required this.AnalyticsCookies,
    required this.MarketingCookies,
    required this.SocialMediaCookies,
  });

  factory ContactConsentTrackingPermissionModel.fromJson(
      Map<String, dynamic>? rawJson) {
    return ContactConsentTrackingPermissionModel(
      TermsAndConditions: rawJson?["terms_and_conditions"] ?? true,
      PrivacyOverview: rawJson?["privacy_overview"] ?? true,
      NecessaryCookies: rawJson?["necessary_cookies"] ?? true,
      PreferencesCookies: rawJson?["preferences_cookies"] ?? true,
      AnalyticsCookies: rawJson?["analytics_cookies"] ?? true,
      MarketingCookies: rawJson?["marketing_cookies"] ?? true,
      SocialMediaCookies: rawJson?["social_media_cookies"] ?? true,
    );
  }

  static List<ContactConsentTrackingPermissionModel> toList(
      List<Map<String, dynamic>>? rawItems) {
    if (rawItems == null) {
      return [];
    }

    List<ContactConsentTrackingPermissionModel> items = [];
    for (int i = 0; i < rawItems.length; i++) {
      items.add(ContactConsentTrackingPermissionModel.fromJson(rawItems[i]));
    }

    return items;
  }
}

class ContactConsentContactingPermissionModel {
  final bool? Email;
  final bool? SMS;
  final bool? Line;
  final bool? Facebook;
  final bool? MobileNotification;

  ContactConsentContactingPermissionModel({
    required this.Email,
    required this.SMS,
    required this.Line,
    required this.Facebook,
    required this.MobileNotification,
  });

  factory ContactConsentContactingPermissionModel.fromJson(
      Map<String, dynamic>? rawJson) {
    return ContactConsentContactingPermissionModel(
        Email: rawJson?["email"] ?? true,
        SMS: rawJson?["sms"] ?? true,
        Line: rawJson?["line"] ?? true,
        Facebook: rawJson?["facebook"] ?? true,
        MobileNotification: rawJson?["mobile_notification"] ?? true,
    );
  }

  static List<ContactConsentContactingPermissionModel> toList(
      List<Map<String, dynamic>>? rawItems) {
    if (rawItems == null) {
      return [];
    }

    List<ContactConsentContactingPermissionModel> items = [];
    for (int i = 0; i < rawItems.length; i++) {
      items.add(ContactConsentContactingPermissionModel.fromJson(rawItems[i]));
    }

    return items;
  }
}

class ContactConsentModel {
  final String ContactId;
  final String ConsentMessageId;
  final String ConsentType;
  final bool ShowConsentBar;
  final bool NeedConsentReview;
  final ContactConsentTrackingPermissionModel TrackingPermission;
  final ContactConsentContactingPermissionModel ContactingPermission;

  ContactConsentModel({
    required this.ContactId,
    required this.ConsentMessageId,
    required this.ConsentType,
    required this.ShowConsentBar,
    required this.NeedConsentReview,
    required this.TrackingPermission,
    required this.ContactingPermission,
  });

  factory ContactConsentModel.fromJson(Map<String, dynamic>? rawJson) {
    return ContactConsentModel(
      ContactId: rawJson?["contact_id"],
      ConsentMessageId: rawJson?["consent_message_id"],
      ConsentType: rawJson?["consent_type"],
      ShowConsentBar: rawJson?["show_consent_bar"],
      NeedConsentReview: rawJson?["need_consent_review"],
      TrackingPermission: ContactConsentTrackingPermissionModel.fromJson(
          rawJson?["tracking_permission"]),
        ContactingPermission: ContactConsentContactingPermissionModel.fromJson(rawJson?["contacting_permission"]),
    );
  }

  static List<ContactConsentModel> toList(
      List<Map<String, dynamic>>? rawItems) {
    if (rawItems == null) {
      return [];
    }

    List<ContactConsentModel> items = [];
    for (int i = 0; i < rawItems.length; i++) {
      items.add(ContactConsentModel.fromJson(rawItems[i]));
    }

    return items;
  }
}
