import 'dart:convert';
import 'package:flutter/services.dart' show rootBundle;
import 'package:flutter_apns/apns.dart';
import 'package:flutter_apns/flutter_apns.dart';
import 'package:pam_flutter/models/pam_message_model.dart';
import 'package:pam_flutter/pam_flutter.dart';

class PamNotification {
  PamNotification._();

  static String? _appPrefix;
  static late PushConnector _connector;

  static Future<String> appPrefix() async {
    if (_appPrefix == null) {
      String raw = await rootBundle.loadString("pam-config.json");
      Map<String, dynamic> cfg = json.decode(raw);
      _appPrefix = cfg["app-prefix"];
    }
    return _appPrefix!;
  }

  static Future<void> pamInitial() async {
    _connector = createPushConnector();
    // _connector.configure(
    //   onLaunch: _onLaunch,
    //   onResume: _onResume,
    //   onMessage: _onMessage,
    // );
  }

  static Future<void> askNotificationPermission() async {
    _connector.requestNotificationPermissions();
    if (_connector.token.value != null) {
      Pam.trackSavePush(token: _connector.token.value!);
    }
  }

  // static Future<bool> _onLaunch(RemoteMessage rm) async {
  //   return isPamMessageReceived(PamStandardCallback.on_launch, rm.data);
  // }
  //
  // static Future<bool> _onResume(RemoteMessage rm) async {
  //   return isPamMessageReceived(PamStandardCallback.on_resume, rm.data);
  // }
  //
  // static Future<bool> _onMessage(RemoteMessage rm) async {
  //   return isPamMessageReceived(PamStandardCallback.on_message, rm.data);
  // }

  static Future<bool> isPamMessageReceived(
      String callback,
      Map<String, dynamic>? message) async {
    if (message == null) {
      return false;
    }
    if (message["pam"] == null) {
      return false;
    }

    Map<String, dynamic> rawPam = json.decode(message["pam"] ?? "{}");
    PamMessageModel pam = PamMessageModel.fromJson(await appPrefix(), rawPam);

    Pam.dispatch(callback, pam.toMap());
    return true;
  }
}
